# Tachyons

## Installation (from PyPI)
```bash
pip install tachyons
```

## Installation (from github, using SSH, branch: main)
```bash
pip install git+ssh://git@github.com/Abdelmathin/tachyons.git@main
```

## Installation (from github, using SSH, branch: dev)
```bash
pip install git+ssh://git@github.com/Abdelmathin/tachyons.git@dev
```

## Uninstallation

```bash
pip uninstall tachyons
```


```bash
python3 -m "tachyons" --create-entrypoints --project-name="my_project" --target-dir="."
```

```bash
python3 -m "tachyons" --create-entrypoints --project-name="my_project" --target-dir="." --next-config=next.config.ts
```
